==> ejc-jltest-impl-3.0.0-20240311.091845-55-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlanaDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 安措费使用计划明细A
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_plana_detail")
public class PlanaDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plana_id")
    private Long planaId; // 主表主键ID
    @TableField(value="detail_name")
    private String detailName; //  安全费用项目名称
    @TableField(value="detail_mny")
    private BigDecimal detailMny; // 拟投入金额
    @TableField(value="detail_time")
    private Date detailTime; // 使用时间
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    
    
    

    public Long getPlanaId() {
        return planaId;
    }

    public void setPlanaId(Long planaId) {
        this.planaId = planaId;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public Date getDetailTime() {
        return detailTime;
    }

    public void setDetailTime(Date detailTime) {
        this.detailTime = detailTime;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}

==> ejc-jltest-impl-3.0.0-20240318.094635-75-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlanaDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 安措费使用计划明细A
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_plana_detail")
public class PlanaDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plana_id")
    private Long planaId; // 主表主键ID
    @TableField(value="detail_name")
    private String detailName; //  安全费用项目名称
    @TableField(value="detail_mny")
    private BigDecimal detailMny; // 拟投入金额
    @TableField(value="detail_max_mny")
    private BigDecimal detailMaxMny; // 最大拟投入金额
    @TableField(value="org_id")
    private Long orgId; // 组织Id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_type")
    private Integer orgType; // 组织类型
    @TableField(value="detail_time")
    private Date detailTime; // 使用时间
    @TableField(value="detail_memo")
    private String detailMemo; // 备注

    public BigDecimal getDetailMaxMny() {
        return detailMaxMny;
    }

    public void setDetailMaxMny(BigDecimal detailMaxMny) {
        this.detailMaxMny = detailMaxMny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getOrgType() {
        return orgType;
    }

    public void setOrgType(Integer orgType) {
        this.orgType = orgType;
    }

    public Long getPlanaId() {
        return planaId;
    }

    public void setPlanaId(Long planaId) {
        this.planaId = planaId;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public Date getDetailTime() {
        return detailTime;
    }

    public void setDetailTime(Date detailTime) {
        this.detailTime = detailTime;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}
